export declare const Operator: {
    at: string;
    not: string;
    missing: string;
    has: string;
    any: string;
    in: string;
    fulltext: string;
    similar: string;
    "number.gt": string;
    "number.lt": string;
    "number.inRange": string;
    "date.before": string;
    "date.after": string;
    "date.between": string;
    "date.day-of-month": string;
    "date.day-of-month-after": string;
    "date.day-of-month-before": string;
    "date.day-of-week": string;
    "date.day-of-week-after": string;
    "date.day-of-week-before": string;
    "date.month": string;
    "date.month-before": string;
    "date.month-after": string;
    "date.year": string;
    "date.hour": string;
    "date.hour-before": string;
    "date.hour-after": string;
    "geopoint.near": string;
};
export declare function AtPredicate(fragment: string, value: string): string;
export declare function NotPredicate(fragment: string, value: string): string;
export declare function MissingPredicate(fragment: string): string;
export declare function HasPredicate(fragment: string): string;
export declare function AnyPredicate(fragment: string, values: string[]): string;
export declare function InPredicate(fragment: string, values: string[]): string;
export declare function FulltextPredicate(fragment: string, value: string): string;
export declare function SimilarPredicate(documentId: string, maxResults: number): string;
export declare function GtPredicate(fragment: string, value: number): string;
export declare function LtPredicate(fragment: string, value: number): string;
export declare function InRangePredicate(fragment: string, before: number, after: number): string;
export declare function DateBeforePredicate(fragment: string, before: Date): string;
export declare function DateAfterPredicate(fragment: string, after: Date): string;
export declare function DateBetweenPredicate(fragment: string, before: Date, after: Date): string;
export declare function DayOfMonthPredicate(fragment: string, day: number): string;
export declare function DayOfMonthAfterPredicate(fragment: string, day: number): string;
export declare function DayOfMonthBeforePredicate(fragment: string, day: number): string;
export declare function DayOfWeekPredicate(fragment: string, day: number): string;
export declare function DayOfWeekAfterPredicate(fragment: string, day: number): string;
export declare function DayOfWeekBeforePredicate(fragment: string, day: number): string;
export declare function MonthPredicate(fragment: string, month: number | string): string;
export declare function MonthBeforePredicate(fragment: string, month: number | string): string;
export declare function MonthAfterPredicate(fragment: string, month: number | string): string;
export declare function YearPredicate(fragment: string, year: number): string;
export declare function HourPredicate(fragment: string, hour: number): string;
export declare function HourBeforePredicate(fragment: string, hour: number): string;
export declare function HourAfterPredicate(fragment: string, hour: number): string;
export declare function NearPredicate(fragment: string, latitude: number, longitude: number, radius: number): string;
export declare const Predicates: {
    at: (fragment: string, value: string) => string;
    not: (fragment: string, value: string) => string;
    missing: (fragment: string) => string;
    has: (fragment: string) => string;
    any: (fragment: string, values: string[]) => string;
    in: (fragment: string, values: string[]) => string;
    fulltext: (fragment: string, value: string) => string;
    similar: (documentId: string, maxResults: number) => string;
    gt: (fragment: string, value: number) => string;
    lt: (fragment: string, value: number) => string;
    inRange: (fragment: string, before: number, after: number) => string;
    before: (fragment: string, before: Date) => string;
    after: (fragment: string, after: Date) => string;
    between: (fragment: string, before: Date, after: Date) => string;
    dayOfMonth: (fragment: string, day: number) => string;
    dayOfMonthAfter: (fragment: string, day: number) => string;
    dayOfMonthBefore: (fragment: string, day: number) => string;
    dayOfWeek: (fragment: string, day: number) => string;
    dayOfWeekAfter: (fragment: string, day: number) => string;
    dayOfWeekBefore: (fragment: string, day: number) => string;
    month: (fragment: string, month: string | number) => string;
    monthBefore: (fragment: string, month: string | number) => string;
    monthAfter: (fragment: string, month: string | number) => string;
    year: (fragment: string, year: number) => string;
    hour: (fragment: string, hour: number) => string;
    hourBefore: (fragment: string, hour: number) => string;
    hourAfter: (fragment: string, hour: number) => string;
    near: (fragment: string, latitude: number, longitude: number, radius: number) => string;
};
